import {
  Metadata,
  Http,
} from '@zeedhi/core';
import {
  Modal,
  ModalService,
  Form,
  Select,
  SelectMultiple,
  StateType,
} from '@zeedhi/common';

export class AutomaticProfileAccessRegistrationController {
  private modalAutomaticRegistration!: Modal;

  public async createAutomaticProfileAccessRegistration() {
    this.modalAutomaticRegistration = await ModalService.createFromJson(
      '/modals/automaticProfileAccessRegistrationModal', true,
    );
  }

  public openAutomaticProfileAccessRegistration() {
    this.modalAutomaticRegistration.show();
  }

  public closeAutomaticProfileAccessRegistration() {
    const form = Metadata.getInstance<Form>('automaticRegistrationForm');
    const indicator = form.getChildInstance<SelectMultiple>('isVisibleIndicators');
    const exceptionByOperator = form.getChildInstance<SelectMultiple>('exceptionByOperator');
    
    indicator.disabled = true;
    exceptionByOperator.disabled = true;
    
    form.clearForm();
    this.modalAutomaticRegistration.hide();
  }
  
  public isAllUnits : StateType = 'N';
  
  public isUseStandardParameterization : StateType = 'N';

  public selectedStandardParameterization({ component }) {
    const form = Metadata.getInstance<Form>('automaticRegistrationForm');
    const panel = form.getChildInstance<Select>('panelCode');
    const indicator = form.getChildInstance<SelectMultiple>('isVisibleIndicators');
    const exceptionByOperator = form.getChildInstance<SelectMultiple>('exceptionByOperator');
    const profile = form.getChildInstance<SelectMultiple>('accessProfileAutomaticRegistration');
    
    if (component.value === 'S') {
      panel.disabled = true;
      panel.value = '';
      profile.disabled = true;
      profile.value = [];
      indicator.disabled = true;
      indicator.value = [];
      exceptionByOperator.disabled = true;
      exceptionByOperator.value = [];
    } else {
      panel.disabled = false;
      profile.disabled = false;
      indicator.disabled = false;
      exceptionByOperator.disabled = false;
    }
  }
  
  public selectionAllUnits({ component }) {
    const form = Metadata.getInstance<Form>('automaticRegistrationForm');
    const cdfilial = form.getChildInstance<SelectMultiple>('automaticRegistrationUnit');
    if (component.value === 'S') {
      cdfilial.value = [];
      cdfilial.disabled = true;
    } else {
      cdfilial.disabled = false;
    }
  }
  
  public panelNumberSelected({ component }) {
    const form = Metadata.getInstance<Form>('automaticRegistrationForm');
    const indicator = form.getChildInstance<SelectMultiple>('isVisibleIndicators');
    if (component.value != null) {
      if (component.value.NRPAINEL) {
        indicator.disabled = false;
        const nrpainel = {
          NRPAINEL: component.value.NRPAINEL,
        };
        indicator.datasource.setFilter(nrpainel);
      }
    } else {
      indicator.disabled = true;
      indicator.value = [];
    }
  }
  
  public profileAccessSelected({ component }) {
    const form = Metadata.getInstance<Form>('automaticRegistrationForm');
    const exceptionByOperator = form.getChildInstance<SelectMultiple>('exceptionByOperator');
    
    exceptionByOperator.disabled = !component.value.length;

    const nrperfilacesso = `_${component.value.join('_')}_`;
    const filterData = {
      NRPERFILACESSO: nrperfilacesso,
    };
    exceptionByOperator.datasource.setFilter(filterData);
  }
  
  public saveAutomaticRegistration() {
    const form = Metadata.getInstance<Form>('automaticRegistrationForm');
    const conditions = form.value;
    Http.post('/saveAutomaticRegistration', {
      requestType: 'Row',
      row: conditions,
    });
  }
}
